@@ -29,6 +29,9 @@ def main():
     global libusedict
     # print(sys.argv) #debug
     codefile = sys.argv[-1]
+    if codefile == 'zlcython' or codefile == "__main__.py":
+        print('错误：请输入代码文件名！')
+        return
     encodefile = codefile.replace(".zlcy", ".py")
     decodecode = ''
     code = []
